==> kdesvn-1.4.1.tar.bz2: kdesvn-1.4.1/src/svnfrontend/frontendtypes.h <==
/***************************************************************************
 *   Copyright (C) 2005-2009 by Rajko Albrecht  ral@alwins-world.de        *
 *   http://kdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef FRONTEND_TYPES_H
#define FRONTEND_TYPES_H

#include "svnqt/shared_pointer.hpp"
#include <QList>

class ThreadContextListener;
class SvnItem;

typedef svn::smart_pointer<ThreadContextListener> ThreadContextListenerP;

typedef QList<SvnItem*> SvnItemList;
typedef QList<SvnItem*>::iterator SvnItemListIterator;
typedef QList<SvnItem*>::const_iterator SvnItemListConstIterator;

#endif

==> kdesvn_1.5.5.orig.tar.bz2: kdesvn-1.5.5/src/svnfrontend/frontendtypes.h <==
/***************************************************************************
 *   Copyright (C) 2005-2009 by Rajko Albrecht  ral@alwins-world.de        *
 *   http://kdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef FRONTEND_TYPES_H
#define FRONTEND_TYPES_H

#include "svnqt/shared_pointer.h"
#include <QList>

class ThreadContextListener;
class SvnItem;

typedef svn::smart_pointer<ThreadContextListener> ThreadContextListenerP;

typedef QList<SvnItem*> SvnItemList;
typedef QList<SvnItem*>::iterator SvnItemListIterator;
typedef QList<SvnItem*>::const_iterator SvnItemListConstIterator;

#endif
